@@ -158,7 +158,7 @@ static void ParseSystemHeader(BitFile *bitFilePtr)
    BitFileReadBits(bitFilePtr,1,"marker_bit (should be 1)"); 
    BitFileReadBits(bitFilePtr,5,"video_bound"); 
    BitFileReadBits(bitFilePtr,1,"packet_rate_restriction_flag"); 
-   BitFileReadBits(bitFilePtr,8,"reserved_byte"); 
+   BitFileReadBits(bitFilePtr,7,"reserved_byte (misnomer)"); 
    while(BitFilePeekBits(bitFilePtr,1,NULL) == 1) {
       BitFileReadBits(bitFilePtr,8,"stream_id");
       BitFileReadBits(bitFilePtr,2,"'11'");
